@@ -6,10 +6,9 @@ import os
 import re
 import sys
 from contextlib import contextmanager
-from functools import wraps
 from importlib.metadata import version as pkgversion
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable
+from typing import TYPE_CHECKING
 
 from duty import duty, tools
 
@@ -26,6 +25,8 @@ CI = os.environ.get("CI", "0") in {"1", "true", "yes", ""}
 WINDOWS = os.name == "nt"
 PTY = not WINDOWS and not CI
 MULTIRUN = os.environ.get("MULTIRUN", "0") == "1"
+PY_VERSION = f"{sys.version_info.major}{sys.version_info.minor}"
+PY_DEV = "314"
 
 
 def pyprefix(title: str) -> str:
@@ -35,21 +36,6 @@ def pyprefix(title: str) -> str:
     return title
 
 
-def not_from_insiders(func: Callable) -> Callable:
-    @wraps(func)
-    def wrapper(ctx: Context, *args: Any, **kwargs: Any) -> None:
-        origin = ctx.run("git config --get remote.origin.url", silent=True)
-        if "pawamoy-insiders/griffe" in origin:
-            ctx.run(
-                lambda: False,
-                title="Not running this task from insiders repository (do that from public repo instead!)",
-            )
-            return
-        func(ctx, *args, **kwargs)
-
-    return wrapper
-
-
 @contextmanager
 def material_insiders() -> Iterator[bool]:
     if "+insiders" in pkgversion("mkdocs-material"):
@@ -84,7 +70,7 @@ def check(ctx: Context) -> None:
     """Check it all!"""
 
 
-@duty
+@duty(nofail=PY_VERSION == PY_DEV)
 def check_quality(ctx: Context) -> None:
     """Check the code quality."""
     ctx.run(
@@ -93,7 +79,7 @@ def check_quality(ctx: Context) -> None:
     )
 
 
-@duty
+@duty(nofail=PY_VERSION == PY_DEV)
 def check_docs(ctx: Context) -> None:
     """Check if the documentation builds correctly."""
     Path("htmlcov").mkdir(parents=True, exist_ok=True)
@@ -105,7 +91,7 @@ def check_docs(ctx: Context) -> None:
         )
 
 
-@duty
+@duty(nofail=PY_VERSION == PY_DEV)
 def check_types(ctx: Context) -> None:
     """Check that the code is correctly typed."""
     os.environ["MYPYPATH"] = "src"
@@ -116,7 +102,7 @@ def check_types(ctx: Context) -> None:
     )
 
 
-@duty
+@duty(nofail=PY_VERSION == PY_DEV)
 def check_api(ctx: Context, *cli_args: str) -> None:
     """Check for API breaking changes."""
     ctx.run(
@@ -143,39 +129,13 @@ def docs(ctx: Context, *cli_args: str, host: str = "127.0.0.1", port: int = 8000
 
 
 @duty
-def docs_deploy(ctx: Context, *, force: bool = False) -> None:
-    """Deploy the documentation to GitHub pages.
-
-    Parameters:
-        force: Whether to force deployment, even from non-Insiders version.
-    """
+def docs_deploy(ctx: Context) -> None:
+    """Deploy the documentation to GitHub pages."""
     os.environ["DEPLOY"] = "true"
     with material_insiders() as insiders:
         if not insiders:
             ctx.run(lambda: False, title="Not deploying docs without Material for MkDocs Insiders!")
-        origin = ctx.run("git config --get remote.origin.url", silent=True, allow_overrides=False)
-        if "pawamoy-insiders/mkdocstrings" in origin:
-            ctx.run(
-                "git remote add org-pages git@github.com:mkdocstrings/mkdocstrings.github.io",
-                silent=True,
-                nofail=True,
-                allow_overrides=False,
-            )
-            ctx.run(
-                tools.mkdocs.gh_deploy(remote_name="org-pages", force=True),
-                title="Deploying documentation",
-            )
-        elif force:
-            ctx.run(
-                tools.mkdocs.gh_deploy(remote_name="org-pages", force=True),
-                title="Deploying documentation",
-            )
-        else:
-            ctx.run(
-                lambda: False,
-                title="Not deploying docs from public repository (do that from insiders instead!)",
-                nofail=True,
-            )
+        ctx.run(tools.mkdocs.gh_deploy(remote_name="org-pages", force=True), title="Deploying documentation")
 
 
 @duty
@@ -199,7 +159,6 @@ def build(ctx: Context) -> None:
 
 
 @duty
-@not_from_insiders
 def publish(ctx: Context) -> None:
     """Publish source and wheel distributions to PyPI."""
     if not Path("dist").exists():
@@ -213,7 +172,6 @@ def publish(ctx: Context) -> None:
 
 
 @duty(post=["build", "publish", "docs-deploy"])
-@not_from_insiders
 def release(ctx: Context, version: str = "") -> None:
     """Release a new Python package.
 
@@ -224,7 +182,7 @@ def release(ctx: Context, version: str = "") -> None:
         ctx.run("false", title="A version must be provided")
     ctx.run("git add pyproject.toml CHANGELOG.md", title="Staging files", pty=PTY)
     ctx.run(["git", "commit", "-m", f"chore: Prepare release {version}"], title="Committing changes", pty=PTY)
-    ctx.run(f"git tag {version}", title="Tagging commit", pty=PTY)
+    ctx.run(f"git tag -m '' -a {version}", title="Tagging commit", pty=PTY)
     ctx.run("git push", title="Pushing commits", pty=False)
     ctx.run("git push --tags", title="Pushing tags", pty=False)
 
@@ -237,20 +195,15 @@ def coverage(ctx: Context) -> None:
     ctx.run(tools.coverage.html(rcfile="config/coverage.ini"))
 
 
-@duty
-def test(ctx: Context, *cli_args: str, match: str = "") -> None:  # noqa: PT028
-    """Run the test suite.
-
-    Parameters:
-        match: A pytest expression to filter selected tests.
-    """
-    py_version = f"{sys.version_info.major}{sys.version_info.minor}"
-    os.environ["COVERAGE_FILE"] = f".coverage.{py_version}"
+@duty(nofail=PY_VERSION == PY_DEV)
+def test(ctx: Context, *cli_args: str) -> None:
+    """Run the test suite."""
+    os.environ["COVERAGE_FILE"] = f".coverage.{PY_VERSION}"
+    os.environ["PYTHONWARNDEFAULTENCODING"] = "1"
     ctx.run(
         tools.pytest(
             "tests",
             config_file="config/pytest.ini",
-            select=match,
             color="yes",
         ).add_args("-n", "auto", *cli_args),
         title=pyprefix("Running tests"),
